==> antd-pro-toolkit-0.6.0.tgz: package/es/NumberInfo/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

import React from 'react';
import { Icon } from 'antd';
import classNames from 'classnames';
import './index.less';

var NumberInfo =
/*#__PURE__*/
function (_React$Component) {
  _inherits(NumberInfo, _React$Component);

  function NumberInfo() {
    _classCallCheck(this, NumberInfo);

    return _possibleConstructorReturn(this, _getPrototypeOf(NumberInfo).apply(this, arguments));
  }

  _createClass(NumberInfo, [{
    key: "render",
    value: function render() {
      var _a = this.props,
          theme = _a.theme,
          title = _a.title,
          subTitle = _a.subTitle,
          total = _a.total,
          subTotal = _a.subTotal,
          status = _a.status,
          suffix = _a.suffix,
          gap = _a.gap,
          rest = __rest(_a, ["theme", "title", "subTitle", "total", "subTotal", "status", "suffix", "gap"]);

      return React.createElement("div", _extends({
        className: classNames("numberInfo", _defineProperty({}, "numberInfo".concat(theme), theme))
      }, rest), title && React.createElement("div", {
        className: "numberInfoTitle",
        title: typeof title === 'string' ? title : ''
      }, title), subTitle && React.createElement("div", {
        className: "numberInfoSubTitle",
        title: typeof subTitle === 'string' ? subTitle : ''
      }, subTitle), React.createElement("div", {
        className: "numberInfoValue",
        style: gap ? {
          marginTop: gap
        } : undefined
      }, React.createElement("span", null, total, suffix && React.createElement("em", {
        className: "suffix"
      }, suffix)), (status || subTotal) && React.createElement("span", {
        className: "subTotal"
      }, subTotal, status && React.createElement(Icon, {
        type: "caret-".concat(status)
      }))));
    }
  }]);

  return NumberInfo;
}(React.Component);

export { NumberInfo as default };

==> antd-pro-toolkit-0.6.8.tgz: package/es/NumberInfo/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

import React from 'react';
import classNames from 'classnames';
import { CaretUpFilled, CaretDownFilled } from '@ant-design/icons';
import './index.less';

var NumberInfo =
/*#__PURE__*/
function (_React$Component) {
  _inherits(NumberInfo, _React$Component);

  function NumberInfo() {
    _classCallCheck(this, NumberInfo);

    return _possibleConstructorReturn(this, _getPrototypeOf(NumberInfo).apply(this, arguments));
  }

  _createClass(NumberInfo, [{
    key: "render",
    value: function render() {
      var _a = this.props,
          theme = _a.theme,
          title = _a.title,
          subTitle = _a.subTitle,
          total = _a.total,
          subTotal = _a.subTotal,
          status = _a.status,
          suffix = _a.suffix,
          gap = _a.gap,
          rest = __rest(_a, ["theme", "title", "subTitle", "total", "subTotal", "status", "suffix", "gap"]);

      return React.createElement("div", _extends({
        className: classNames("numberInfo", _defineProperty({}, "numberInfo".concat(theme), theme))
      }, rest), title && React.createElement("div", {
        className: "numberInfoTitle",
        title: typeof title === 'string' ? title : ''
      }, title), subTitle && React.createElement("div", {
        className: "numberInfoSubTitle",
        title: typeof subTitle === 'string' ? subTitle : ''
      }, subTitle), React.createElement("div", {
        className: "numberInfoValue",
        style: gap ? {
          marginTop: gap
        } : undefined
      }, React.createElement("span", null, total, suffix && React.createElement("em", {
        className: "suffix"
      }, suffix)), (status || subTotal) && React.createElement("span", {
        className: "subTotal"
      }, subTotal, status == "up" && React.createElement(CaretUpFilled, null), status == "down" && React.createElement(CaretDownFilled, null))));
    }
  }]);

  return NumberInfo;
}(React.Component);

export { NumberInfo as default };
